summaryrefslogtreecommitdiff
path: root/linux/drm.h
diff options
context:
space:
mode:
authorIan Romanick <idr@us.ibm.com>2002-12-05 15:28:13 +0000
committerIan Romanick <idr@us.ibm.com>2002-12-05 15:28:13 +0000
commita790687c9a4b369094a2a56e29a8240db573a54a (patch)
treed6a1201e666b487fac353e4aa70312ee1646c33c /linux/drm.h
parent9cfbdbadecaa7f2c89bd361d157e23a885ae5d10 (diff)
Massive trunk-to-branch merge. This includes the Mesa-5.x updates.texmem-0-0-1-20030123-trunk-premerge
Diffstat (limited to 'linux/drm.h')
-rw-r--r--linux/drm.h21
1 files changed, 17 insertions, 4 deletions
diff --git a/linux/drm.h b/linux/drm.h
index f26d4442..d3c9f158 100644
--- a/linux/drm.h
+++ b/linux/drm.h
@@ -346,17 +346,30 @@ typedef struct drm_irq_busid {
} drm_irq_busid_t;
typedef enum {
- _DRM_VBLANK_ABSOLUTE = 0x0, /* Wait for specific vblank sequence number */
- _DRM_VBLANK_RELATIVE = 0x1 /* Wait for given number of vblanks */
+ _DRM_VBLANK_ABSOLUTE = 0x0, /* Wait for specific vblank sequence number */
+ _DRM_VBLANK_RELATIVE = 0x1, /* Wait for given number of vblanks */
+ _DRM_VBLANK_SIGNAL = 0x80000000 /* Send signal instead of blocking */
} drm_vblank_seq_type_t;
-typedef struct drm_radeon_vbl_wait {
+#define _DRM_VBLANK_FLAGS_MASK _DRM_VBLANK_SIGNAL
+
+struct drm_wait_vblank_request {
+ drm_vblank_seq_type_t type;
+ unsigned int sequence;
+ unsigned long signal;
+};
+
+struct drm_wait_vblank_reply {
drm_vblank_seq_type_t type;
unsigned int sequence;
long tval_sec;
long tval_usec;
-} drm_wait_vblank_t;
+};
+typedef union drm_wait_vblank {
+ struct drm_wait_vblank_request request;
+ struct drm_wait_vblank_reply reply;
+} drm_wait_vblank_t;
typedef struct drm_agp_mode {
unsigned long mode;